@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.5.10"
+__version__ = "0.5.12"
 
 
 import datetime
@@ -76,7 +76,7 @@ class CuJiraX:
         output = {}
         for f in s1.__root__:
             testset_name = f.uri.split("/")[-1]
-            testexecution_name = self.testexecution_name or datetime.date.today().strftime("%Y%m%d") + " :: " + testset_name
+            testexecution_name = self.testexecution_name or testset_name + " :: " + datetime.date.today().strftime("%Y%m%d") 
 
             ticket_ts, ticket_te = [
                 self.jira.create_testset(
@@ -118,8 +118,8 @@ class CuJiraX:
                 self.result_info.summary = testexecution_name
                 self.result_info.description = self.testexecution_desc or f.description or "TBA"
                 
-                _tests = self._get_results(f.elements, self.jira, ignore_duplicate)
-                
+                _tests, _result = self._get_results(f.elements, self.jira, ignore_duplicate)
+                logger.debug("tests:" + str(_tests) + ", result: " + _result)
                 req = result.RequestBody(
                     info=self.result_info,
                     tests= _tests,
@@ -127,6 +127,7 @@ class CuJiraX:
                 )
                 res = result.import_xray_json_results(req)
                 output.update({
+                    'result': _result,
                     'import_result_status': res.status_code,
                     'import_result_response': res.json()
                 })
@@ -145,7 +146,8 @@ class CuJiraX:
 
     @classmethod
     def _get_results(cls, elements: Element, j: JiraX, ignore_duplicate):
-        result_tests = []
+        test_request_obj = []
+        results = []
         for el in elements:
             test_name = cls.scenarioid_to_tescasename(el.id, el.keyword)
             tests = j.get_tests(test_name)
@@ -160,8 +162,10 @@ class CuJiraX:
                     
             statuses = [step.result.status.value for step in el.steps]
             agg_result = "passed" if all(s == 'passed' for s in statuses) else "failed"
-            result_tests.append(result.Test(testKey=str(test_key), status=agg_result))
-        return result_tests
+            test_request_obj.append(result.Test(testKey=str(test_key), status=agg_result))
+            results.append(agg_result)
+        grand_result = "passed" if all(s == 'passed' for s in results) else "failed"
+        return test_request_obj, grand_result
 
     @classmethod
     def _split_elements_to_exist_and_new(cls, elements: Element, j: JiraX, ignore_duplicate):
