@@ -59,8 +59,8 @@ class JiraX(Jira):
         return self.get_issues(summary=summary, type="Test")
 
     def get_issues(self, summary: str, type: str) -> List[Jirakey]:
-        summary = summary.replace("[", "").replace("]", "")
-        query = f'issuetype="{type}" AND summary~"{summary}" AND project="{self.key}"'
+        _summary = summary.replace("[", "").replace("]", "")
+        query = f'issuetype="{type}" AND summary~"{_summary}" AND project="{self.key}"'
         issues = self.jql(query).get("issues")
         
         return [Jirakey(issue.get('key')) for issue in issues if issue.get('fields')['summary'] == summary]
